@@ -1,7 +1,6 @@
 import time
-from dataclasses import dataclass
-
-from typing import List, Optional, Dict
+from typing import List, Optional
+from pydantic import BaseModel, validate_arguments
 
 import invertedai as iai
 from invertedai.api.config import TIMEOUT, should_use_mock_api
@@ -10,21 +9,18 @@ from invertedai.api.mock import (
     get_mock_birdview,
     get_mock_infractions,
 )
-from invertedai.error import APIConnectionError
-
+from invertedai.error import APIConnectionError, InvalidInput
 from invertedai.common import (
     AgentState,
     RecurrentState,
     Image,
     InfractionIndicators,
     AgentAttributes,
-    TrafficLightId,
-    TrafficLightState,
+    TrafficLightStatesDict,
 )
 
 
-@dataclass
-class DriveResponse:
+class DriveResponse(BaseModel):
     """
     Response returned from an API call to :func:`iai.drive`.
     """
@@ -46,12 +42,13 @@ class DriveResponse:
     ]  #: For each agent, indicates whether the predicted state is inside supported area.
 
 
+@validate_arguments
 def drive(
     location: str,
     agent_states: List[AgentState],
     agent_attributes: List[AgentAttributes],
     recurrent_states: List[RecurrentState],
-    traffic_lights_states: Optional[Dict[TrafficLightId, TrafficLightState]] = None,
+    traffic_lights_states: Optional[TrafficLightStatesDict] = None,
     get_birdview: bool = False,
     get_infractions: bool = False,
     random_seed: Optional[int] = None,
@@ -97,7 +94,12 @@ def drive(
     --------
     :func:`initialize`
     :func:`location_info`
+    :func:`light`
     """
+    if len(agent_states) != len(agent_attributes):
+        raise InvalidInput("Incompatible Number of Agents in either 'agent_states' or 'agent_attributes'.")
+    if len(agent_states) != len(recurrent_states):
+        raise InvalidInput("Incompatible Number of Agents in either 'agent_states' or 'recurrent_states'.")
 
     if should_use_mock_api():
         agent_states = [mock_update_agent_state(s) for s in agent_states]
@@ -144,13 +146,13 @@ def drive(
                     AgentState.fromlist(state) for state in response["agent_states"]
                 ],
                 recurrent_states=[
-                    RecurrentState(r) for r in response["recurrent_states"]
+                    RecurrentState.fromval(r) for r in response["recurrent_states"]
                 ],
-                birdview=Image(response["birdview"])
+                birdview=Image.fromval(response["birdview"])
                 if response["birdview"] is not None
                 else None,
                 infractions=[
-                    InfractionIndicators(*infractions)
+                    InfractionIndicators.fromlist(infractions)
                     for infractions in response["infraction_indicators"]
                 ]
                 if response["infraction_indicators"]
